<?php
/*

 $Id: autoreg.php 3544 2005-01-04 19:03:27Z philips $
 $HeadURL: https://svn.osuosl.org/public/maintain2/tags/release-2.4.2-RC2/docs/modules/autoreg.php $

 Copyright (c) 2002 Oregon State University - Network Engineering
 All rights reserved.

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*!
	@header Autoregistration Document
	This is the autoreg page, It uses a different header and footer. You will only
	See this page if you don't have access to any zones or click on the link within
	Maintain. Autoregistration depends on the $conf['module']->autoreg configs, currently
	there is support for multiple "AutoReg" sites, see config for examples
*/

/* Start House Keeping */
	
	require "../../modules/config.php";

	// do anything that needs to be done here
        if (!check_session()) { logout(); }
	
	// setup the user environment
	setup_user_environment($action, $zone_id);

/* End House Keeping */

/*  Make needed objects */
if (!$autoreg_type) { $autoreg_type = $user->autoreg_type; }
$info = $conf['modules']->get_info('autoreg');
$ip = new IP(0);

$source_ip = $ip->ip2int($_SERVER['REMOTE_ADDR']);

// If they are on a free ip address we need to figure out which autoreg they want to use
foreach ($info['site'] as $site_name) {

	if ($info['free_start'][$site_name] <= $source_ip && $info['free_end'][$site_name] >= $source_ip) {

		$autoreg_type = $site_name;
		$user->autoreg_type = $autoreg_type;

	} // end if the ip is inside the free zone

} // end foreach

$autoreg = new Autoreg($user->username,$user->autoreg_type);

// Check to make sure they have an autoreg_type
if (!$autoreg_type && !$action) {
	header("Location: " . $conf['web_path'] . "/modules/autoreg_portal.php");
	exit();
}



// If this site uses the ACL we need to check and make sure that
// this user is allowed to get here...

if ($info['acl'][$autoreg_type]) {
	// if false re-direct them
	if (!$autoreg->has_acl_access($user->username,$autoreg_type)) {
		$user->autoreg_type = false;
		show_template('autoreg_header');
		require($conf['prefix'] . "/templates/autoreg_acl_denied.inc");
		exit();
	}

} // if acl

if ($agree || $user->agree) { $aup = "accepted"; } 

// if we can't find the headers
if (!$info['header'][$autoreg_type]) {
	$autoreg_type = $autoreg->get_type($conf['zone']->name);
} 


require( $conf['prefix'] . "/" . $info['header']["$autoreg_type"] );




 
/*!
	@function update_host
	@discussion called when we are updating an existing host
*/
if ($action == "update_host") {

        //create the objects so we can do a bunch of checking
        $host = new Host($host_id);

        //remove any non-valid chr's from the mac addie
        $mac = $conf['ui']->clean_hardware_address($mac);
	
	// Get all the ranges for this autoreg type
	$ranges = $autoreg->get_autoreg_ranges($autoreg_type);

	if ($mac === '0060089a42ad') {
		$conf['error']->add_error('ha', "00-60-08-9A-42-AD is the example address");
	}
	if (substr($mac,0,2) == '44') { 
		$conf['error']->add_error('ha', "You have entered a 44- address, these are used only by dial-up adapters");
	}

        //check the HW Addie if it has changed
	if ($host->ha != $mac) {
		$host->zone->id = $autoreg->get_zone_id();

		// go through all the ranges in this autoreg
		foreach ($ranges as $range) { 
		        $host->check_hardware_address($mac,0,$range->id);
		} 

	} // end if HA has changed

        //if no error found
        if (!$conf['error']->error_state AND $user->username = $host->other_id) {

                $autoreg->update_host($host_id,$mac,$hardware_type,$user->username);

		//Get all other hosts inside "Public" autoreg sites and nuke those as well..
		foreach ($info['cross_populate'] as $key => $cross_populate) {
			if ($key != $autoreg_type AND $cross_populate) {
				$auto_host = $autoreg->get_host($host->ha,$key);

			        // Get all the ranges for this autoreg type
			        $auto_ranges = $autoreg->get_autoreg_ranges($autoreg_type);	
				
				foreach ($auto_ranges as $range) {
					$auto_host->check_hardware_address($mac,0,$range->id);
                                        if ($conf['error']->error_state) { break; }
				}
				if (!$conf['error']->error_state) { 
					$autoreg->update_host($auto_host->id,$mac,$hardware_type,$user->username,$key,"auto_add");
				} // end if now errors
			} // end if the autoreg is not the current one

		} // end foreach
		if (!preg_match("/autoreg_portal.php/",$_SERVER['HTTP_REFERER'])) { $link = $conf['web_path'] . "/modules/autoreg.php?aup=accepted&amp;autoreg_type=$autoreg_type"; }
		else { $link = $conf['web_path'] . "/modules/autoreg_portal.php?agree=on"; }
		$conf['ui']->display_confirmation("Host Updated", "Your Computer has been update the change will come into effect in 5 to 10 min.", $link);

        } //no error found

	else {
		echo "<p><font size=\"+2\"><b>The Following Error(s) Occured</b></font></p>";
		$conf['error']->show_message('ha');
		if (!preg_match("/autoreg_portal.php/",$_SERVER['HTTP_REFERER'])) { $link = $conf['web_path'] . "/modules/autoreg.php?aup=accepted&amp;autoreg_type=$autoreg_type"; }
		else { $link = $conf['web_path'] . "/modules/autoreg_portal.php?agree=on"; }
		echo "<br /><br /><a href=\"$link\">[Continue]</a>";
	} //end else

} // update_host

/*!
	@function delete
	@discussion deleting a autoreg host, when doing this they must be the user ($host->other_id) or an admin
*/
elseif ($action == "Delete") {
	$host = new Host($host_id); 
	$ha = $host->ha;

	if ($user->username == $host->other_id OR $user->is_admin) { 
		$host->delete();

		//Get all other hosts inside "Public" autoreg sites and nuke those as well..
		foreach ($info['cross_populate'] as $key => $cross_populate) {
			if ($key != $autoreg_type AND $cross_populate) {
				$auto_host = $autoreg->get_host($ha,$key);
				$auto_host->delete();
			} 

		} // end foreach
		if (!preg_match("/autoreg_portal.php/",$_SERVER['HTTP_REFERER'])) { $link = $conf['web_path'] . "/modules/autoreg.php?aup=accepted&amp;autoreg_type=$autoreg_type"; }
		else { $link = $conf['web_path'] . "/modules/autoreg_portal.php?agree=on"; }
		$conf['ui']->display_confirmation("Host Deleted", "Your Computer has been deleted from our records.", $link);
	} // check perms

	else {
		$conf['ui']->show_access_denied();
	}
	
} //delete

// we are making a new entry
elseif ($action == "new_host") {
	//create the objects so we can do a bunch of checking
	$host = new Host(0);

	//remove any non-valid chr's from the mac addie
	$mac = $conf['ui']->clean_hardware_address($mac);

	if ($mac === '0060089a42ad') {
		$conf['error']->add_error('ha', "00-60-08-9A-42-AD is the example address");
	}

        if (substr($mac,0,2) == '44') {
                $conf['error']->add_error('ha', "You have entered a 44- address, these are used only by dial-up adapters");
        }

	$ranges = $autoreg->find_autoreg_dynamic();
	$host->zone->id = $autoreg->get_zone_id();
	
	//check the HW Addie
	foreach ($ranges as $range) {
		$host->check_hardware_address($mac,0,$range->id);
		if ($conf['error']->error_state) { break; }
	}

	//if no error found
	if (!$conf['error']->error_state) {

		$autoreg->add_host($mac,$hardware_type,$user->username);
		// Add this host to all other "Public" sites
		foreach ($info['cross_populate'] as $key => $cross_populate) {
			// If it's not the current site and it's public let's roll
			if ($key != $autoreg_type AND $cross_populate) {
				$ranges = $autoreg->find_autoreg_dynamic($key);
			        
				foreach ($ranges as $range) {
					$host->check_hardware_address($mac,0,$range->id);
					if ($conf['error']->error_state) { break; }
				} // End Foreach
				if (!$conf['error']->error_state) {	
					$autoreg->add_host($mac,$hardware_type,$user->username,$key,"auto_add");
				}

			}

		} // End foreach

		if (!preg_match("/autoreg_portal.php/",$_SERVER['HTTP_REFERER'])) { $link = $conf['web_path'] . "/modules/autoreg.php?aup=accepted&amp;autoreg_type=$autoreg_type"; }
		else { $link = $conf['web_path'] . "/modules/autoreg_portal.php?agree=on"; }
		$conf['ui']->display_confirmation("Host Added", "Your Computer has been added, it should be live in 5 to 10 min.", $link);

	} //no error found

		else {
		echo "<p><font size=\"+2\"><b>The Following Error(s) Occured</b></font></p>";
		$conf['error']->show_message('ha');
		if (!preg_match("/autoreg_portal.php/",$_SERVER['HTTP_REFERER'])) { $link = $conf['web_path'] . "/modules/autoreg.php?aup=accepted&amp;autoreg_type=$autoreg_type"; }
		else { $link = $conf['web_path'] . "/modules/autoreg_portal.php?agree=on"; }
		echo "<br /><br /><a href=\"$link\">[Continue]</a>";
	} //end else

} //new_host

/*!
	@function create_host
	@discussion Admin Create, actually create the host
*/
elseif ($action == "create_host" AND $user->has_access($conf['zone']->id)) {

        //create the objects so we can do a bunch of checking
        $host = new Host(0);

        //remove any non-valid chr's from the mac addie
        $mac = $conf['ui']->clean_hardware_address($mac);

        if ($expire) {
                $expire = $conf['ui']->clean_expire_date($expire);
                if (time() > $expire) {
                        $conf['error']->add_error('expire',"Invalid Expire date set in the past");
                }
                if ($expire == -1) {
                        $conf['error']->add_error('expire',"Invalid Expire value. Example 03/27/1984 (MM/DD/YYYY)");
                }
        } // if expire

	if ($mac === '0060089a42ad') {
		$conf['error']->add_error('ha', "00-60-08-9A-42-AD is the example address");
	}

        if (substr($mac,0,2) == '44') {
                $conf['error']->add_error('ha', "You have entered a 44- address, these are used only by dial-up adapters");
        }

        $ranges = $autoreg->find_autoreg_dynamic();
        $host->zone->id = $autoreg->get_zone_id();

	//check the username against ldap
	$error = $user->check_auth_name($username);
	if (!$error) {
		$conf['error']->add_error('username',"Invalid username");
	}

        //check the HW Addie
        foreach ($ranges as $range) {
                $host->check_hardware_address($mac,0,$range->id);
                if ($conf['error']->error_state) { break; }
        }

        //if no error found
        if (!$conf['error']->error_state) {
		if (!$comment) { $comment = "Administrative Add by $user->username"; }

                $host_id = $autoreg->add_host($mac,$type,$username,$autoreg_type,0,$comment);
		$host = new Host($host_id); 
		if ($use_expire) { $host->update_expire($expire); }

                // Add this host to all other "Public" sites
                foreach ($info['cross_populate'] as $key => $cross_populate) {
                        // If it's not the current site and it's public let's roll
                        if ($key != $autoreg_type AND $cross_populate) {
                                $ranges = $autoreg->find_autoreg_dynamic($key);

                                foreach ($ranges as $range) {
                                        $host->check_hardware_address($mac,0,$range->id);
                                        if ($conf['error']->error_state) { break; }
                                } // End Foreach
                                if (!$conf['error']->error_state) {
                                        $autoreg->add_host($mac,$type,$username,$key,"auto_add","Administrative Add by $user->username");
                                }

                        }

                } // End foreach
		
		$conf['ui']->display_confirmation("Host Added", "$username's Computer has been added.", $conf['web_path'] . "/index.php");
	}

	else {
		$action = "show_create_host";
	}

} // create_host


/*!
	@function disable_autoreg_hosts
	@discussion disables the hosts of a specific user and allows you to give a reason
*/
elseif ($action == 'disable_autoreg_hosts') {

	//First get the hosts
	$user_autoreg = new Autoreg($other_id);
	$hosts = $user_autoreg->hosts;
	$comment = "[disable]" . $comment;

	foreach ($hosts as $host) {
		$host = new Host($host->id);
		$host->update_status('disabled');
		$host->object_history->update($user->username,$comment);
	}

	$conf['ui']->display_confirmation("Hosts Disabled","$other_id's hosts have been disabled", $conf['web_path'] . "/index.php");

} // disable_autoreg_hosts

/********************
  DISPLAY IF BLOCK
********************/

/*!
	@function show_create_host
	@discussion Shows the Admin Host create.
*/
if ($action == "show_create_host" AND $user->has_access($conf['zone']->id)) {

	require ($conf['prefix'] . "/templates/show_autoreg_create_host.inc");

} // show_create_host
/*!
	@function show_find_hosts
	@discussion shows a template for finding hosts based on usernames
*/
elseif ($action == 'show_find_hosts') {
        show_template('show_autoreg_find_host');
}
/*!
	@function show_found_hosts
	@discussion shows the hosts found from find_hosts
*/
elseif ($action == 'show_found_hosts') {
	
	$user_autoreg = new Autoreg($other_id,$user->autoreg_type);
	$hosts = $user_autoreg->hosts;

	if ($hosts) { 
		require ($conf['prefix'] . "/templates/show_autoreg_find_hosts.inc");
	}
	else {
		echo "<p align=\"center\" class=\"fatalerror\">No Hosts Found</p>";
	}

} // show_found_hosts

/****************************************************************
Ok now they are here let's go ahead and make a new autoreg object
****************************************************************/


if (($autoreg->hosts or $aup == "accepted") AND !$action AND !$autoreg->disabled) {
	$autoreg->show_autoreg($autoreg_type, $info);
	
} 

elseif ($autoreg->disabled && !$action) { 
	show_template ('autoreg_disabled'); 
}

//if they don't have any hosts then we need to show them the AUP
elseif ($aup != "accepted") {
	require ($conf['prefix'] . "/templates/show_autoreg_aup.inc");
}

require ( $conf['prefix'] . "/" . $info['footer'][$autoreg_type] );



?>


