<?php
/*

 $Id: mx.php 3544 2005-01-04 19:03:27Z philips $
 $HeadURL: https://svn.osuosl.org/public/maintain2/tags/release-2.4.2-RC2/docs/mx.php $

 Copyright (c) 2002 Oregon State University - Network Engineering
 All rights reserved.

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*!
	@header MX Record Document
	The main document for editing and viewing mx records. handles actions that come from the web interface.

*/


/* Start House Keeping */
	
	require "../modules/config.php";

	// do anything that needs to be done here
        if (!check_session()) { logout(); }
	
	// setup the user environment
	setup_user_environment($action, $zone_id);

/* End House Keeping */

$mx = new mx($mx_id);
if ($domain_select == "admin") { $domain_id = $admin_domain_id; }
if ($domain_id) { $domain = new Domain($domain_id); }

show_template('header'); 

?>
<p align="left" class="header1">Manage MX Records</p>
<? 

/*!
	@function update
	@discussion updateing a mx record, we also make sure they have access to the mx record
*/
if ($action == 'update' ) {

	// Show access denied if they shouldn't be here
	if (!$user->has_access($mx->zone->id)) { 
		$conf['ui']->show_access_denied();
		exit();
	}

	// ok were updating, check to make sure data is valid first
	if ( strcasecmp($mx->name,$name) ) {
		$mx->check_name($name,$domain,$priority,$server); 
	}

	// check the server only if it has changed
	if ($server != $mx->server) { 
		$mx->check_server($server);
	}

	// let's do some checking to make sure that nobody
	// has updated this record since it was viewed
	$history = $mx->object_history->get_history();
	if ($history->date != $last_update) { 
		$conf['error']->add_error('general', "Error this MX record has been updated since the last read, Please try again");
	}

	// check the priority only if it has changed
	if ($priority != $mx->priority) { 
		$mx->check_priority($name,$domain,$priority);
	}

	// check if domain has changed
	if (($domain_id != $mx->domain->id)) {
		$mx->check_name($name,$domain,$priority,$server);
	}

        // Make sure they have picked a ttl that is valid
        if (!is_numeric($ttl) || $ttl < 300) {
                $conf['error']->add_error('ttl',"Invalid TTL");
        }

	

	if (!$conf['error']->error_state)  {
		// if the data is valid then update into the database
		$mx->update_domain($domain_id);
		$mx->update_server($server);
		$mx->update_name($name);
		$mx->update_priority($priority);
		$mx->update_ttl($ttl);
		$mx->object_history->update($user->username,$comment);
		$action_type = "modified";
		
		$conf['ui']->display_confirmation("MX Record Updated","The Mx Record $mx->hostname has been updated correctly", $conf['web_path'] . "/mx.php?action=show_mx&amp;mx_id=$mx_id&amp;$action_type=modified");
		
	} // no error
	// If an error has occured
	else {
		$action = 'show_mx';
	} // if error

} // update

/*!
	@function really_delete
	@discussion really delete the mx record, checks to make sure they have access
*/
elseif ($action == 'really_delete') {


	if ($user->has_access($mx->zone->id)) { 
		$mx->delete_item($mx_id);

		// display delete confirmation and then go home!
		$conf['ui']->display_confirmation("MX Record Deleted", "The MX record $mx->name has been deleted.",$conf['web_path'] . "/mx.php?action=show_mxs");
	} // if has access

	else {
		$conf['ui']->show_access_denied();
		exit();
	} 

} // really_delete

/*!
	@functoin really_move
	@discussion Moves the mx record between zones.
*/
elseif ($action == "really_move") { 

	//let's check one last time to make sure they are a admin
	if ($user->is_admin) {
		//identity confirmed..... time to rock and roll
		$mx->move_mx($mx_id,$zone_id);
		$zone = new Zone($zone_id); 
		$conf['ui']->display_confirmation("MX Record Moved", "The MX record $mx->hostname has been moved to $zone->name.", $conf['web_path'] . "/mx.php?action=show_mx&amp;mx_id=$mx_id");
	} // if admin

} // really_move

/*****************
 DISPLAY IF BLOCK 
*****************/

/*!
	@function show_mx
	@discussion display the mx record
*/
if ($action == "show_mx" OR $action == "edit") {
	$conf['ui']->show_mx($mx,$action_type);
} // show_mx

/*!
	@function show_mxs
	@discussion display man mx records, shows a listing
*/
elseif ($action == "show_mxs") {

	//if we pass it a zone id then switch conf to match. 
	if ($view_zone_id)  {
		$conf['zone'] = new Zone($view_zone_id);
	}
	
	// create the view
        $sql = "SELECT id FROM zone_mx WHERE zone=" . $conf['zone']->id;
        $user->view = new View($sql);

        if ($sort_type) {
                $user->view->initialize($sort_type,$sort_offset);
        }

        else {
                $user->view->initialize('id', $sort_offset);
        }

	// grab a array of objects
	$mxs = $conf['ui']->get_mxs();
	// get the total number of items
	$total_items = mysql_num_rows(mysql_query($user->view->get_sql(), $conf['dbh']));

	if ($total_items > "0")  {
		// if there are results run the view
		$conf['script'] = "mx.php";
		$conf['ui']->show_mxs($mxs, $total_items);
	}
	else {
		echo "<br /><br /><p align=\"center\" class=\"header1\">No MX Records were found in " . $conf['zone']->name . "</p>";
		echo "<br /><br /><br /><br /><br /><br /><br /><br /><br /><br /><br /><br /><br />\n";
		$user->view = false;
	}
} // show_mxs

/*!
	@function delete
	@discussion show the confirmation of a mx delete
*/
elseif ($action == "delete" || $action == "Delete") {

	// ok were deleting, let's check and make sure they are sure
	$conf['ui']->show_confirm($conf['web_path'] . "/mx.php?action=really_delete&amp;mx_id=$mx_id","Are you sure you want to delete the MX record $mx->hostname?");

} // delete

/*!
	@function move
	@discussion show the confirmation of a mx range move
*/
elseif ($action == "move") { 

	//ok let's confirm that they want to move this mx record to a differnet zone
	$zone = new Zone($zone_id); 
	$conf['ui']->show_confirm($conf['web_path'] . "/mx.php?action=really_move&amp;mx_id=$mx_id&amp;zone_id=$zone_id", "Are you sure you want to move $mx->hostname to $zone->name?");

} //move_mx

show_template('footer'); 


?>
