<?php
/*

 $Id: option.php 3544 2005-01-04 19:03:27Z philips $
 $HeadURL: https://svn.osuosl.org/public/maintain2/tags/release-2.4.2-RC2/docs/option.php $

 Copyright (c) 2002 Oregon State University - Network Engineering
 All rights reserved.

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*!
	@header DHCP Options Document
	This is a subdocment of workgoups and subnets, it is never referenced on it's own, simply called for functions.
*/

/* Start House Keeping */

	require("../modules/config.php");

	// make sure they are supposed to be here
        if (!check_session()) { logout(); }
	
	setup_user_environment($action, $zone_id);

/* End House Keeping */

// Only admins and zone admins should be here
if ( ! $user->is_admin && !$user->is_zone_admin) {
        header("Location: " . $conf['web_path'] . "/index.php");
	exit();
}

show_template('header');
echo "<p class=\"header1\">Managing DHCP Options</p>";
/*****************
 START WORK BLOCK
*****************/

// Depending on the type create a object
if ($type == 'host') { 
	$object = new Host($type_id);
}
elseif ($type == 'workgroup') { 
	$object = new Workgroup($type_id);
}
elseif ($type == 'subnet') { 
	$object = new Subnet($type_id);
}

$option = new Option($option_id);

/*!
	@function create_option
	@discussion new create option, used the object_option table
		you have to pass a object, it's scope && type
*/
if ($action === 'create_option') {

	// Check and make sure they didn't make a host level subnet etc..
	if (!$option->check_scope($scope,$type)) {
		$conf['error']->add_error('scope',"This Scope now allowed with this DHCP option type");
	}

	$option->dhcp_option = $dhcp_option;
	$option->dhcp_option_name = $option->get_option_name($dhcp_option);

	$option->check_option_value($dhcp_option,$value);

	// Add catching for subnet && not a full admin
	if ($type === 'subnet' && !$user->is_admin) {
		$conf['ui']->show_access_denied();
		exit();
	}
	
	// Add catching for workgroup and less than zone admin
	if ($type === 'workgroup' && $user->has_access($conf['zone']->id) < 50) {
		$conf['ui']->show_access_denied();
		exit();
	}

	if ($type === 'host' && !$user->has_access($object->zone->id)) {
		$conf['ui']->show_access_denied();
		exit();
	}

	if (!$conf['error']->error_state) {

		$option_id = $option->create_option($type_id,$type,$scope,$dhcp_option,$value);
		$option = new Option($option_id);

		$conf['ui']->display_confirmation("DHCP Option created", "The $type DHCP option has been created", $conf['web_path'] . "/option.php?action=show_options&amp;object_id=$type_id&amp;type=$type");

	} // if no error

	else {
		$action = 'show_create_option';
	} //an error occured

} // create_option

/*!
	@action create_admin_option
	@discussion creates a new dhcp option that
		can be assigned to objects later
*/
elseif ($action == 'create_admin_option') { 

        /* Create a new admin object */
        $admin_option = new AdminOption(0);

        if (!$user->is_admin) {
                $conf['ui']->show_access_denied();
                exit();
        }

        /* Let's check their info out */
        if (!$admin_option->check_name($name)) {
                $conf['error']->add_error('option_name', "Error DHCP option names can only contain A-Z 0-9, . and -");
        }

        if (!$admin_option->check_space($space) && $is_custom) {
                $conf['error']->add_error('option_space', "Error Space names must be A-Z 0-9");
        }

        /* If nothing bad has happened keep going */
        if (!$conf['error']->error_state) {

                $admin_option->create($name, $option_type, $access, $is_custom, $space, $value);
                $conf['ui']->display_confirmation("DHCP Option Created", "$name has been added as a valid DHCP option", $conf['web_path'] . '/option.php?action=show_admin_options');

        } // no errors

        else {
                $action == 'show_create_admin_option';
        }
	

} // create_admin_option

/*!
	@action update_option
	@discussion updated the dhcp option this can
		update any type of option
*/
elseif ($action == 'update_option') {

	if (!$option->has_access($user->username)) {
		$conf['ui']->show_access_denied();
		exit();
	}
        
	// Check and make sure they didn't make a host level subnet etc..
        if (!$option->check_scope($scope,$type)) {
                $conf['error']->add_error('scope',"This Scope now allowed with this DHCP option type");
        }
	
	$option->check_option_value($dhcp_option,$value);
	

	if (!$conf['error']->error_state) {

		$option->update_value($value);
		$option->update_option($dhcp_option);
		$option->update_scope($scope);

		$conf['ui']->display_confirmation("DHCP Option Updated", "Your DHCP option has been updated", $conf['web_path'] . "/option.php?action=show_options&object_id=$object_id&type=$type");

	} // no errors

	else {
		$action = 'show_edit';
	}

} // update_option


// this we're really deleting this zone
elseif ( $action == 'delete') {

	if (!$user->is_admin && $user->has_access($zone_id) < 50) {
		$conf['ui']->show_access_denied();
		exit();
	}

	$option->delete();

	$conf['ui']->display_confirmation("DHCP Option deleted","The dhcp option has been deleted", $conf['web_path'] . "/option.php?action=show_options&object_id=$object_id&type=$type");

	
} // if we are deleting

/*!
	@action delete_admin
	@discussion deletes a actually dhcp option 
*/
if ($action == 'delete_admin') {

	if (!$user->is_admin) {
		$conf['ui']->show_access_denied();
		exit();
	}

	$adminoption = new AdminOption($option_id);
	$adminoption->delete();

	$conf['ui']->display_confirmation("DHCP Option removed", "$adminoption->name has been removed from maintain", $conf['web_path'] . "/option.php?action=show_admin_options");

} // admin_delete

/****************************
*****************************
     START DISPLAY BLOCK
*****************************
*****************************/

?>
<font class="header1"><?= $title; ?></font>
<?

/*!
	@function confirm_delete
	@discussion confirm that you really want to delete the 
		selected dhcp option
*/
if ($action == 'confirm_delete') {

	$conf['ui']->show_confirm($conf['web_path'] . "/option.php?action=delete&type=$type&type_id=$type_id&next_page=$next_page&next_action=$next_action&zone_id=$zone_id", "Are you sure you want to delete this DHCP option");


} // confirm_delete

/*!
	@action show_edit
	@discussion display a page to edit a single option on
		we will need to re-pass the next_page && the 
		next_action
*/
elseif ($action == 'show_edit') {
	if (!$user->has_access($zone_id) < 50 && !$user->is_admin) {
		$conf['ui']->show_access_denied();
		exit();
	}
	require ($conf['prefix'] . "/templates/show_option.inc");

} // show_edit

/*!
	@action show_admin_option
	@discussion shows a single admin option
*/
elseif ( $action == 'show_admin_option') { 

	if (!$user->is_admin) { 
		$conf['ui']->show_access_denied(); 
		exit();
	}

	$adminoption = new AdminOption($option_id);

	require ($conf['prefix'] . "/templates/show_admin_option.inc");

} // show_admin_option

elseif ( $action == 'edit' || $action == 'show_create' ) {
	// show the range edit form
	$conf['ui']->show_option($action, $type, $type_id, $option);
}

/*!
	@function edit_host_option
	@discussion edits a host DHCP option
*/
elseif ($action == 'show_edit_host') { 
	$option = new Option($option_id,$type);
	require ($conf['prefix'] . "/templates/show_host_option.inc");
} // show_host_accountant

/*!
	@action show_options
	@dicussion displays many options, based on type
	@param type	The type of object we need to show the options for
	@param type_id	The ID of the object we need to show
	@param page	The final page we go to if we need to get back to this object
	@param next_action The final action we need to do to get back to this object 
*/
elseif ( $action == 'show_options' ) {
	$options = $conf['ui']->get_options("SELECT id FROM object_option WHERE type='$type' AND object_id='$object_id'");	
	$conf['ui']->show_options($action, $type, $object_id, $options);
 } // show_options

/*!
	@action show_create_option
	@discussion display the create page for a new
		dhcp option, this is a universal page for all options
*/
elseif ($action === 'show_create_option') {
	require($conf['prefix'] . "/templates/show_create_option.inc");
}

/*!
	@action show_create_admin_option
	@discussion Show the create page for new DHCP option (admin)
		this works for custom and non-custom dhcp options
*/
elseif ($action === 'show_create_admin_option') {

	require($conf['prefix'] . "/templates/show_create_admin_option.inc");

} // show_create_admin_option


/*!
	@action show_admin_options
	@discussion Shows all of the dhcp options currently allowed inside maintain
*/
elseif ($action === 'show_admin_options') {

	if (! $user->view ) {
		$user->view = new View("SELECT id FROM dhcp_options");
	} 

	$conf['script'] = 'option.php';
	$conf['action'] = 'show_admin_options';

	if ($sort_type) { 
		$user->view->initialize($sort_type,$sort_offset);
	}
	else {
		$user->view->initialize('name',$sort_offset);
	}

	// We need all of the options here
	$options = $conf['ui']->get_admin_options();

	$sql = "SELECT count(id) FROM dhcp_options";
	$db_results = mysql_query($sql, dbh());
	$results = mysql_fetch_row($db_results);

	$total_items = array_pop($results);
	
	require($conf['prefix'] . "/templates/show_admin_options.inc");

} // show_admin_options

/*!
	@action confrim_admin_delete
	@discussion Shows a confirmation dialogue asking if you really want to nuke
		a dhcp option
*/
elseif ($action === 'confirm_admin_delete') {

	if (!$user->is_admin) {
		$conf['ui']->show_access_denied();
		exit();
	}

	$adminoption = new AdminOption($option_id);

	// Use child mojo to check for kiddies

	$conf['ui']->show_confirm($conf['web_path'] . "/option.php?action=delete_admin&option_id=$option_id", "Are you sure you want to delete $adminoption->name");


} // confirm_admin_delete


?>

<? show_template('footer'); ?>
