<?php

/*

 Copyright (c) 2002 Oregon State University - Network Engineering
 All rights reserved.

 $Id: cname.php 3567 2005-02-04 18:21:04Z philips $
 $HeadURL: https://svn.osuosl.org/public/maintain2/tags/release-2.4.2-RC2/modules/class/cname.php $

 The cname record object ... functions for manipulating & changing

*/

class CNAME {
	var $id;
	var $name;
	var $host;
	var $domain; // this is a domain_id
	var $server; // the server that we are pointing this CNAME to
	var $hostname;
	var $zone; // this is the zone_id

	var $object_history;

	// we can populate this stuff from the database -- no sense in
	//   passing it in.
	function CNAME ( $cname_id = 0 ) {
		global $conf;

		$this->id = $cname_id;

		$info = $this->get_info();

		if ($info) {
			$this->host        = $info->host;
			$this->domain      = new Domain($info->domain);
			$this->server      = $info->server;
			$this->hostname    = $info->name . "." . $this->domain->name;
			$this->name        = $info->name;
			$this->zone        = new Zone($info->zone);
			$this->last_update = $info->last_update;
			$this->who_update  = $info->who_update;
			$this->comment     = $info->comment;
			$this->ttl	   = $info->ttl;
		} //end if info

		$this->object_history = new ObjectHistory('cname', $this->id);

	} // CNAME

	function get_info () {
		global $conf;

		$sql = "SELECT * FROM zone_cname WHERE id='$this->id'";
		$db_result = mysql_query($sql, $conf['dbh']);

		return mysql_fetch_object($db_result);

	} // get_info

	function update_name ($newname) {
		$this->update_item('name',$newname);
		$this->name = $newname;
	}
	function update_domain ($newdomain) {
		$this->update_item('domain', $newdomain);
		$this->domain = new Domain($newdomain);
	}
	function update_server ($newserver) {
		$this->update_item('server', $newserver);
		$this->server = $newserver;
	}
	function update_ttl($ttl) {
		$this->update_item('ttl',$ttl);
		$this->ttl = $ttl;
	}
	// end of the update functions

	// called but other functions simply does the db mojo
	function update_item($type,$new_item) 
	{
		global $conf;
		
		$sql = "UPDATE zone_cname SET $type='$new_item' WHERE id='$this->id'";
		$db_results = mysql_query($sql, $conf['dbh']);
	} // update_item

	/*!
		@function move_cname
		@discussion moves the cname from one zone to another
			this can only be done by admins
	*/
	function move_cname($cname_id, $zone_id) { 
		global $user;

		$zone = new Zone($zone_id);
		
		$sql = "UPDATE zone_cname SET zone='$zone_id' WHERE id='$cname_id'";
		$db_results = mysql_query($sql, dbh());

		$this->object_history->insert($user->username,'cname',$this->id,time(),"Moved $this->hostname to $zone->name");

	} // move_cname

	/*!
		@function check_name
		@discussion takes the CNAME and the domain and make sure it isn't
			overlapping with anything else
	*/
	function check_name($name,$domain) {
		global $conf, $user;

		// first let's make sure it isn't in the db already
		$sql = "SELECT * FROM zone_cname WHERE name LIKE '$name' AND domain='$domain->id'";
		$db_results = mysql_query($sql,$conf['dbh']);
		$count = mysql_num_rows($db_results);
		if ($count) 
			{ 
				$conf['error']->add_error('name', "$name.$domain->name is already in use by a CNAME."); 
				return false;
			}

               // now we need to check to make sure there isn't a Cname with this name.
                $sql = "SELECT * FROM host WHERE name LIKE '$name' AND domain='$domain->id'";
                $db_results = mysql_query($sql, $conf['dbh']);
                $host_info = mysql_fetch_object($db_results);

                if ($host_info) {
                        $conf['error']->add_error('name', "$name.$domain->name is already in use by a Host.");
                }

                //now check the MX records...
                $sql = "SELECT * FROM zone_mx WHERE name LIKE '$name' AND domain='$domain->id'";
                $db_results = mysql_query($sql, $conf['dbh']);
                $host_info = mysql_fetch_object($db_results);

                if ($host_info) {
                        $conf['error']->add_error('name', "$name.$domain->name is already in use by a MX Record.");
                }

		// now check the PTR records
		$hostname = $name .".". $domain->name;
		$sql = "SELECT id FROM pointer WHERE hostname LIKE '$hostname' AND type='forward'";
		$db_results = mysql_query($sql, $conf['dbh']);
		$host_info = mysql_fetch_array($db_results);

		if ($host_info) { 
			$conf['error']->add_error('name',"$name.$domain->name is already in use by a Forward Pointer");
		}

		// next let's make sure there aren't invalid chr's in it
		if (!(preg_match("/^[A-Za-z0-9\-]+$/", $name))) {
				$conf['error']->add_error('name', "$name is an invalid cname.");
		}		

		if (preg_match("/\.$/", $name)) {
			$conf['error']->add_error('name', "$name is an invalid cname.");
		}

	} // check_name

	/*!
		@function check_server
		@discussion checks the server entry for a cname
	*/
        function check_server($server) {
                global $conf, $user;
	
		$data = split_hostname($server);
		
		//first let's see if there is a host with this record we use this later..
		$sql = "SELECT host.id FROM host,domain WHERE host.domain=domain.id AND domain.name='$data->domain' AND host.name='$data->name'";
		$db_results = mysql_query($sql, $conf['dbh']);
		if (mysql_fetch_object($db_results)) {
			$host_exists = 1;
		}
	
		//let's make sure they aren't trying to point it at a mx record
		$sql = "SELECT * FROM zone_mx,domain WHERE zone_mx.domain=domain.id AND domain.name='$data->domain' AND zone_mx.name='$data->name'"; 
		$db_results = mysql_query($sql, $conf['dbh']);
		if (mysql_fetch_object($db_results) && !$host_exists) 
			{
				$conf['error']->add_error('server', "$server is a current MX record.<br />\n Unable to point a CNAME at a MX record");
			}
                //let's make sure there aren't invalid chr's in it
                if (!preg_match ("/^[\w+\.-]+/", $server))
                        {
                                $conf['error']->add_error('server', "$server is an invalid Server");
                        }
        } // check_server

	//takes the cname->id and frys it...
	function delete_item() {
		global $conf,$user;
		
		// Delete the cname
		$sql = "DELETE FROM zone_cname WHERE id='$this->id'";
		$db_results = mysql_query($sql, dbh());

		// Delete any object_history
		$sql = "DELETE FROM object_history WHERE type='cname' AND id='$this->id'";
		$db_results = mysql_query($sql, dbh());

		// Add the deletion record
		$text = "Deleted CNAME " . $this->hostname . " --> " . $this->server;
		$conf['ui']->add_delete_history($this->zone->id,$text,$user->username);
	
	
	} //delete_item
	
	// inserts the new values into the table in a new row
	function new_item($server,$name,$domain,$zone,$ttl = -1)
	{
		global $user, $conf;

		if (!$ttl) {
			$ttl = $conf['default_host_ttl'];
		}
			
	
		$sql = "INSERT INTO zone_cname SET id='', server='$server', name='$name', domain='$domain', zone='$zone', ttl='$ttl'";
		$db_results = mysql_query($sql, $conf['dbh']);
		$cname = mysql_insert_id($conf['dbh']);
		return $cname;


	}	

}

?>
